Index: main/waeup.fceokene/trunk/src/waeup/fceokene/students/utils.py
===================================================================
--- main/waeup.fceokene/trunk/src/waeup/fceokene/students/utils.py	(revision 10286)
+++ main/waeup.fceokene/trunk/src/waeup/fceokene/students/utils.py	(revision 10388)
@@ -27,4 +27,5 @@
 from waeup.kofa.browser.interfaces import IPDFCreator
 from waeup.kofa.students.utils import trans
+from waeup.fceokene.interswitch.browser import GATEWAY_AMT
 
 class CustomStudentsUtils(NigeriaStudentsUtils):
@@ -253,5 +254,7 @@
         payment.p_level = p_level
         payment.p_current = p_current
-        payment.amount_auth = float(amount)
+        # On June 26, 2013 FCEOkene realized that the Interswitch fee
+        # is deducted from their amount. Therefore, we add this fee here.
+        payment.amount_auth = float(amount) + GATEWAY_AMT
         return None, payment
 

Index: main/waeup.fceokene/trunk/src/waeup/fceokene/students/tests/test_browser.py
===================================================================
--- main/waeup.fceokene/trunk/src/waeup/fceokene/students/tests/test_browser.py	(revision 10286)
+++ main/waeup.fceokene/trunk/src/waeup/fceokene/students/tests/test_browser.py	(revision 10388)
@@ -230,5 +230,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 12495.0)
+        self.assertEqual(payment.amount_auth, 12645.0)
         self.assertEqual(payment.p_item, u'CERT1')
         self.assertEqual(error, None)
@@ -243,12 +243,12 @@
         self.assertEqual(payment.p_level, 200)
         self.assertEqual(payment.p_session, 2005)
-        self.assertEqual(payment.amount_auth, 11545.0)
+        self.assertEqual(payment.amount_auth, 11695.0)
         self.assertEqual(payment.p_item, u'CERT1')
         self.assertEqual(error, None)
 
         # UG students pay 65150
         self.certificate.study_mode = 'ug_ft'
         error, payment = utils.setPaymentDetails('schoolfee',self.student)
-        self.assertEqual(payment.amount_auth, 65650.0)
+        self.assertEqual(payment.amount_auth, 65800.0)
         self.assertEqual(error, None)
 
@@ -265,5 +265,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 120.0)
+        self.assertEqual(payment.amount_auth, 270.0)
         self.assertEqual(payment.p_item, u'CERT1')
         self.assertEqual(error, None)
@@ -272,5 +272,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 150.0)
+        self.assertEqual(payment.amount_auth, 300.0)
         self.assertEqual(payment.p_item, u'')
         self.assertEqual(error, None)
@@ -285,5 +285,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 4150.0)
+        self.assertEqual(payment.amount_auth, 4300.0)
         self.assertEqual(payment.p_item, u'My bed coordinates')
         self.assertEqual(error, None)
@@ -293,5 +293,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 2650.0)
+        self.assertEqual(payment.amount_auth, 2800.0)
         self.assertEqual(payment.p_item, u'My bed coordinates')
         self.assertEqual(error, None)
@@ -300,5 +300,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 150.0)
+        self.assertEqual(payment.amount_auth, 300.0)
         self.assertEqual(payment.p_item, u'')
         self.assertEqual(error, None)
@@ -307,5 +307,5 @@
         self.assertEqual(payment.p_level, 100)
         self.assertEqual(payment.p_session, 2004)
-        self.assertEqual(payment.amount_auth, 90.0)
+        self.assertEqual(payment.amount_auth, 240.0)
         self.assertEqual(payment.p_item, u'')
         self.assertEqual(error, None)
@@ -243,12 +243,12 @@
         self.assertEqual(error, None)
 
-        # UG students pay 65150
+        # UG students pay 65800
         self.certificate.study_mode = 'ug_ft'
         error, payment = utils.setPaymentDetails('schoolfee',self.student)